==> jc-1.4.0.tar.gz: polyglot/ext/jl/qq/CUP__24Grm__24actions.h <==
// class polyglot.ext.jl.qq.CUP$Grm$actions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 14e592958761bc4 polyglot_ext_jl_qq_CUP__24Grm__24actions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_qq_CUP__24Grm__24actions_H_
#define _JC_polyglot_ext_jl_qq_CUP__24Grm__24actions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Stack$object;
struct _jc_java__5fcup_runtime_Symbol$object;
struct _jc_java__5fcup_runtime_lr__5fparser$object;
struct _jc_polyglot_ext_jl_qq_Grm$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_refs	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_refs;
typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_nonrefs	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$refs	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$refs;
typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$nonrefs	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object;

typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$fields_struct	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$fields_struct;
typedef const struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vmethods	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vmethods;
typedef const struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtable	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtable;
typedef const struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtype	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtype;

// Class fields structure
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$fields_struct {
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Case;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Catch;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ClassDecl;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ClassMember;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Eval;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Expr;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ForInit;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ForUpdate;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Formal;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Import;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Stmt;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24SwitchElement;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24TypeNode;
	struct _jc_java_lang_Class$object	*class__24polyglot__24parse__24VarDeclarator;
};
extern _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$fields_struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$class_fields;

// Constructors
extern void _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$method$_init$797a615247060490(_jc_env *, struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object *, struct _jc_polyglot_ext_jl_qq_Grm$object *);

// Virtual methods
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$method$CUP__24Grm__24do__5faction$28076d39a52b6154(_jc_env *, struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object *, jint, struct _jc_java__5fcup_runtime_lr__5fparser$object *, struct _jc_java_util_Stack$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$method_info$CUP__24Grm__24do__5faction$28076d39a52b6154;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vmethods {
	struct _jc_java__5fcup_runtime_Symbol$object	*(*CUP__24Grm__24do__5faction$28076d39a52b6154)(_jc_env *, struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object *, jint, struct _jc_java__5fcup_runtime_lr__5fparser$object *, struct _jc_java_util_Stack$object *, jint);
};

// Vtable
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vmethods	polyglot_ext_jl_qq_CUP__24Grm__24actions;
};

// Vtype
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_refs {
	struct _jc_polyglot_ext_jl_qq_Grm$object	*parser;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$refs {
    _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_refs	polyglot_ext_jl_qq_CUP__24Grm__24actions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_nonrefs	polyglot_ext_jl_qq_CUP__24Grm__24actions;
};

// Object instance structure
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object {
	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtype	*vtype;
	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtype _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_qq_CUP__24Grm__24actions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$class_object;

#endif	/* _JC_polyglot_ext_jl_qq_CUP__24Grm__24actions_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/qq/CUP__24Grm__24actions.h <==
// class polyglot.ext.jl.qq.CUP$Grm$actions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 14e592958761bc4 polyglot_ext_jl_qq_CUP__24Grm__24actions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_jl_qq_CUP__24Grm__24actions_H_
#define _JC_polyglot_ext_jl_qq_CUP__24Grm__24actions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Stack$object;
struct _jc_java__5fcup_runtime_Symbol$object;
struct _jc_java__5fcup_runtime_lr__5fparser$object;
struct _jc_polyglot_ext_jl_qq_Grm$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_refs	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_refs;
typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_nonrefs	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$refs	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$refs;
typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$nonrefs	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$nonrefs;
typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object;

typedef struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$fields_struct	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$fields_struct;
typedef const struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vmethods	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vmethods;
typedef const struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtable	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtable;
typedef const struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtype	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtype;

// Class fields structure
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$fields_struct {
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Case;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Catch;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ClassDecl;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ClassMember;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Eval;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Expr;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ForInit;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24ForUpdate;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Formal;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Import;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24Stmt;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24SwitchElement;
	struct _jc_java_lang_Class$object	*class__24polyglot__24ast__24TypeNode;
	struct _jc_java_lang_Class$object	*class__24polyglot__24parse__24VarDeclarator;
};
extern _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$fields_struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$class_fields;

// Constructors
extern void _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$method$_init$797a615247060490(_jc_env *, struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object *, struct _jc_polyglot_ext_jl_qq_Grm$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$method$CUP__24Grm__24do__5faction$28076d39a52b6154(_jc_env *, struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object *, jint, struct _jc_java__5fcup_runtime_lr__5fparser$object *, struct _jc_java_util_Stack$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$method_info$CUP__24Grm__24do__5faction$28076d39a52b6154;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$method$class__24$57cd45dca0be1678(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vmethods {
	struct _jc_java__5fcup_runtime_Symbol$object	*(*CUP__24Grm__24do__5faction$28076d39a52b6154)(_jc_env *, struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object *, jint, struct _jc_java__5fcup_runtime_lr__5fparser$object *, struct _jc_java_util_Stack$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vmethods	polyglot_ext_jl_qq_CUP__24Grm__24actions;
};

// Vtype
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_refs {
	struct _jc_polyglot_ext_jl_qq_Grm$object	*parser;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$refs {
    _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_refs	polyglot_ext_jl_qq_CUP__24Grm__24actions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$sub_nonrefs	polyglot_ext_jl_qq_CUP__24Grm__24actions;
};

// Object instance structure
struct _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$object {
	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtype	*vtype;
	_jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$vtype _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_qq_CUP__24Grm__24actions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_qq_CUP__24Grm__24actions$class_object;

#endif	/* _JC_polyglot_ext_jl_qq_CUP__24Grm__24actions_H_ */
